@@ -22,7 +22,7 @@ module Facter
 
           def codepage
             result = codepage_from_api
-            result.empty? ? codepage_from_registry : result
+            result&.empty? ? codepage_from_registry : result
           end
 
           def codepage_from_registry
@@ -31,8 +31,10 @@ module Facter
           end
 
           def codepage_from_api
-            require 'facter/resolvers/windows/ffi/winnls_ffi'
+            require_relative '../../../facter/resolvers/windows/ffi/winnls_ffi'
             WinnlsFFI.GetACP.to_s
+          rescue LoadError => e
+            log.debug("Could not retrieve codepage: #{e}")
           end
         end
       end
